@@ -6,11 +6,11 @@ setGeneric( "read", function( descriptor, input ){
 setMethod( "read", c( descriptor = "Descriptor" , input = "character" ),
 function(descriptor, input ){
 	file <- file_path_as_absolute( input )
-	.Call( "Descriptor__readMessageFromFile", descriptor@pointer, file, PACKAGE = "RProtoBuf" )
+	.Call(Descriptor__readMessageFromFile, descriptor@pointer, file)
 } )
 
 setMethod( "read", c( descriptor = "Descriptor", input = "raw" ), function(descriptor, input ){
-	.Call( "Descriptor__readMessageFromRawVector", descriptor@pointer, input, PACKAGE="RProtoBuf" )
+	.Call(Descriptor__readMessageFromRawVector, descriptor@pointer, input)
 } )
 
 setMethod( "read", c( descriptor = "Descriptor" ),
@@ -21,7 +21,7 @@ function( descriptor, input ){
 	wasopen <- identical( summary(input)[["opened"]], "opened" )
 	if( !wasopen ) open( input, "rb")
         stopifnot(summary(input)[["text"]] == "binary")
-	message <- .Call( "Descriptor__readMessageFromConnection", descriptor@pointer, input, PACKAGE = "RProtoBuf" )
+	message <- .Call(Descriptor__readMessageFromConnection, descriptor@pointer, input)
 	if( !wasopen ) close( input )
 	message
 } )
@@ -36,8 +36,7 @@ setGeneric( "readASCII", function( descriptor, input, partial=FALSE ){
 setMethod( "readASCII", c( descriptor = "Descriptor" , input = "character" ),
 function(descriptor, input, partial=FALSE){
         stopifnot(is.logical(partial), length(partial) == 1)
-	.Call( "Descriptor__readASCIIFromString", descriptor@pointer, input,
-              partial, PACKAGE = "RProtoBuf" )
+	.Call(Descriptor__readASCIIFromString, descriptor@pointer, input, partial)
 } )
 
 setMethod( "readASCII", c( descriptor = "Descriptor" ),
@@ -49,9 +48,8 @@ function( descriptor, input, partial=FALSE){
 	wasopen <- identical( summary(input)[["opened"]], "opened" )
 	if( !wasopen ) open( input, "rb" )
         stopifnot(summary(input)[["text"]] == "binary")
-	message <- .Call( "Descriptor__readASCIIFromConnection", descriptor@pointer, input,
-                         partial, PACKAGE = "RProtoBuf" )
-        close(input)
+	message <- .Call(Descriptor__readASCIIFromConnection, descriptor@pointer, input, partial)
+    close(input)
 	message
 } )
 
@@ -64,8 +62,7 @@ setGeneric( "readJSON", function( descriptor, input ){
 
 setMethod( "readJSON", c( descriptor = "Descriptor" , input = "character" ),
 function(descriptor, input){
-	.Call( "Descriptor__readJSONFromString", descriptor@pointer, input,
-              PACKAGE = "RProtoBuf" )
+	.Call(Descriptor__readJSONFromString, descriptor@pointer, input)
 } )
 
 setMethod( "readJSON", c( descriptor = "Descriptor" ),
@@ -76,8 +73,7 @@ function( descriptor, input){
 	wasopen <- identical( summary(input)[["opened"]], "opened" )
 	if( !wasopen ) open( input, "rb" )
         stopifnot(summary(input)[["text"]] == "binary")
-	message <- .Call( "Descriptor__readJSONFromConnection", descriptor@pointer, input,
-                         PACKAGE = "RProtoBuf" )
+	message <- .Call(Descriptor__readJSONFromConnection, descriptor@pointer, input)
 	close(input)
 	message
 } )
