@@ -106,7 +106,7 @@ extern SEXP FileOutputStream_new(SEXP, SEXP, SEXP);
 extern SEXP FileOutputStream_SetCloseOnDelete(SEXP, SEXP);
 /*extern SEXP get_method_input_type(SEXP);*/
 extern SEXP get_method_output_prototype(SEXP);
-extern SEXP get_protobuf_library_version();
+extern SEXP get_protobuf_library_version(void);
 extern SEXP get_value_of_enum(SEXP, SEXP);
 extern SEXP getEnumDescriptor(SEXP);
 extern SEXP getExtension_cpp(SEXP, SEXP);
@@ -136,6 +136,7 @@ extern SEXP Message__is_initialized(SEXP);
 extern SEXP Message__length(SEXP);
 extern SEXP Message__merge(SEXP, SEXP);
 extern SEXP Message__num_extensions(SEXP);
+extern SEXP Message__print_text_format(SEXP);
 extern SEXP Message__serialize_to_file(SEXP, SEXP);
 extern SEXP Message__set_field_size(SEXP, SEXP, SEXP);
 extern SEXP Message__set_field_values(SEXP, SEXP, SEXP, SEXP);
@@ -149,7 +150,7 @@ extern SEXP MethodDescriptor__output_type(SEXP);
 extern SEXP newProtocolBufferLookup(SEXP);
 extern SEXP newProtoMessage(SEXP);
 extern SEXP readProtoFiles_cpp(SEXP, SEXP);
-extern SEXP resetDescriptorPool_cpp();
+extern SEXP resetDescriptorPool_cpp(void);
 extern SEXP ServiceDescriptor__as_character(SEXP);
 extern SEXP ServiceDescriptor__as_list(SEXP);
 extern SEXP ServiceDescriptor__as_Message(SEXP);
@@ -296,6 +297,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"Message__merge",                           (DL_FUNC) &Message__merge,                            2},
     {"Message__num_extensions",                  (DL_FUNC) &Message__num_extensions,                   1},
     {"Message__serialize_to_file",               (DL_FUNC) &Message__serialize_to_file,                2},
+    {"Message__print_text_format",               (DL_FUNC) &Message__print_text_format,                1},
     {"Message__set_field_size",                  (DL_FUNC) &Message__set_field_size,                   3},
     {"Message__set_field_values",                (DL_FUNC) &Message__set_field_values,                 4},
     {"Message__swap",                            (DL_FUNC) &Message__swap,                             4},
